pycparser: Parser of the C language in Python
=============================================

Description
-----------

development website: https://github.com/eliben/pycparser

PyPI page: https://pypi.org/project/pycparser/

License
-------

BSD

Upstream Contact
----------------

https://github.com/eliben/pycparser
